# Generated by Django 3.0.11 on 2021-06-30 14:17

from django.db import migrations, models
import django.db.models.deletion
import qrtoolkit_core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0006_auto_20210614_1338'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='apicall',
            name='code',
        ),
        migrations.AddField(
            model_name='apicall',
            name='link_url',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='api_calls', to='qrtoolkit_core.LinkUrl', validators=[qrtoolkit_core.validators.validate_is_api_mode_qrcode]),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='qrcode',
            name='mode',
            field=models.CharField(choices=[('kiosk', 'Kiosk Mode'), ('redirect', 'Redirect Mode'), ('info_page', 'Information Page Mode'), ('api_call', 'Api call Mode')], default='redirect', help_text="\nSets the mode this code is in.<br/>\nKiosk Mode: Show buttons to choose a link from<br/>\nRedirect Mode: Instantly redirects to the url with the highest priority.<br/>\nInformation Page Mode: Show basic info with links to different urls.<br/>\nApi call Mode: Will look for ApiCall's in the database that correspond to the selected link_url, and execute them. (Extended Kiosk mode)\n", max_length=16),
        ),
    ]
