# Generated by Django 3.0.11 on 2021-09-28 11:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0008_auto_20210630_1526'),
    ]

    operations = [
        migrations.AddField(
            model_name='linkurl',
            name='visible',
            field=models.BooleanField(default=True, help_text='Sets the visibility for this link in KIOSK mode.'),
        ),
    ]
